@@ -2,7 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 import sys
-from .main import console_init_logging, main, parse_args
 
-console_init_logging()
+from .main import main, parse_args
+
 sys.exit(main(parse_args()))
